Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1728)

Unified Diff: editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameFunctionProcessorTest.java

Issue 12340077: Initial binding of RenameRefactoring service to Eclipse. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameFunctionProcessorTest.java
diff --git a/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameFunctionProcessorTest.java b/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameFunctionProcessorTest.java
index 50daedba7b120777e5d1d42a9d3912b914591cc2..c41bd29e77e8a6c4e6cb8d34f6af2added0ff8bb 100644
--- a/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameFunctionProcessorTest.java
+++ b/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameFunctionProcessorTest.java
@@ -16,7 +16,7 @@ package com.google.dart.tools.ui.refactoring;
import com.google.dart.tools.core.model.CompilationUnit;
import com.google.dart.tools.core.model.DartFunction;
import com.google.dart.tools.internal.corext.refactoring.rename.RenameFunctionProcessor;
-import com.google.dart.tools.ui.internal.refactoring.RenameSupport;
+import com.google.dart.tools.ui.internal.refactoring.RenameSupport_OLD;
import org.eclipse.ltk.core.refactoring.RefactoringStatus;
import org.eclipse.ui.IWorkbenchWindow;
@@ -29,10 +29,10 @@ import static org.fest.assertions.Assertions.assertThat;
*/
public final class RenameFunctionProcessorTest extends RefactoringTest {
/**
* Uses {@link RenameSupport} to rename {@link DartFunction}.
*/
private static void renameFunction(DartFunction function, String newName) throws Exception {
- RenameSupport renameSupport = RenameSupport.create(function, newName);
+ RenameSupport_OLD renameSupport = RenameSupport_OLD.create(function, newName);
IWorkbenchWindow workbenchWindow = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
renameSupport.perform(workbenchWindow.getShell(), workbenchWindow);
}
@@ -29,10 +29,10 @@ import static org.fest.assertions.Assertions.assertThat;
public final class RenameFunctionProcessorTest extends RefactoringTest {
/**
- * Uses {@link RenameSupport} to rename {@link DartFunction}.
+ * Uses {@link RenameSupport_OLD} to rename {@link DartFunction}.
*/
private static void renameFunction(DartFunction function, String newName) throws Exception {

Powered by Google App Engine
This is Rietveld 408576698